@@ -1,9 +1,21 @@
-from PyObjCTools.TestSupport import *
-
 import CoreWLAN
 import Foundation
+from PyObjCTools.TestSupport import TestCase
+
+
+class TestCoreWLANTypes(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(CoreWLAN.CWChannelBand)
+        self.assertIsEnumType(CoreWLAN.CWChannelWidth)
+        self.assertIsEnumType(CoreWLAN.CWCipherKeyFlags)
+        self.assertIsEnumType(CoreWLAN.CWErr)
+        self.assertIsEnumType(CoreWLAN.CWEventType)
+        self.assertIsEnumType(CoreWLAN.CWIBSSModeSecurity)
+        self.assertIsEnumType(CoreWLAN.CWInterfaceMode)
+        self.assertIsEnumType(CoreWLAN.CWKeychainDomain)
+        self.assertIsEnumType(CoreWLAN.CWPHYMode)
+        self.assertIsEnumType(CoreWLAN.CWSecurity)
 
-class TestCoreWLANTypes (TestCase):
     def testConstants(self):
         self.assertEqual(CoreWLAN.kCWNoErr, 0)
         self.assertEqual(CoreWLAN.kCWEAPOLErr, 1)
@@ -44,6 +56,8 @@ class TestCoreWLANTypes (TestCase):
         self.assertEqual(CoreWLAN.kCWPHYMode11b, 2)
         self.assertEqual(CoreWLAN.kCWPHYMode11g, 3)
         self.assertEqual(CoreWLAN.kCWPHYMode11n, 4)
+        self.assertEqual(CoreWLAN.kCWPHYMode11ac, 5)
+        self.assertEqual(CoreWLAN.kCWPHYMode11ax, 6)
         self.assertEqual(CoreWLAN.kCWInterfaceModeNone, 0)
         self.assertEqual(CoreWLAN.kCWInterfaceModeStation, 1)
         self.assertEqual(CoreWLAN.kCWInterfaceModeIBSS, 2)
@@ -59,6 +73,9 @@ class TestCoreWLANTypes (TestCase):
         self.assertEqual(CoreWLAN.kCWSecurityWPAEnterpriseMixed, 8)
         self.assertEqual(CoreWLAN.kCWSecurityWPA2Enterprise, 9)
         self.assertEqual(CoreWLAN.kCWSecurityEnterprise, 10)
+        self.assertEqual(CoreWLAN.kCWSecurityWPA3Personal, 11)
+        self.assertEqual(CoreWLAN.kCWSecurityWPA3Enterprise, 12)
+        self.assertEqual(CoreWLAN.kCWSecurityWPA3Transition, 13)
         self.assertEqual(CoreWLAN.kCWSecurityUnknown, Foundation.NSIntegerMax)
         self.assertEqual(CoreWLAN.kCWIBSSModeSecurityNone, 0)
         self.assertEqual(CoreWLAN.kCWIBSSModeSecurityWEP40, 1)
@@ -66,6 +83,8 @@ class TestCoreWLANTypes (TestCase):
         self.assertEqual(CoreWLAN.kCWChannelWidthUnknown, 0)
         self.assertEqual(CoreWLAN.kCWChannelWidth20MHz, 1)
         self.assertEqual(CoreWLAN.kCWChannelWidth40MHz, 2)
+        self.assertEqual(CoreWLAN.kCWChannelWidth80MHz, 3)
+        self.assertEqual(CoreWLAN.kCWChannelWidth160MHz, 4)
         self.assertEqual(CoreWLAN.kCWChannelBandUnknown, 0)
         self.assertEqual(CoreWLAN.kCWChannelBand2GHz, 1)
         self.assertEqual(CoreWLAN.kCWChannelBand5GHz, 2)
@@ -78,14 +97,29 @@ class TestCoreWLANTypes (TestCase):
         self.assertEqual(CoreWLAN.kCWNoMemErr, CoreWLAN.kCWNoMemoryErr)
         self.assertEqual(CoreWLAN.kCWUknownErr, CoreWLAN.kCWUnknownErr)
         self.assertEqual(CoreWLAN.kCWFormatErr, CoreWLAN.kCWInvalidFormatErr)
-        self.assertEqual(CoreWLAN.kCWAuthAlgUnsupportedErr, CoreWLAN.kCWAuthenticationAlgorithmUnsupportedErr)
-        self.assertEqual(CoreWLAN.kCWInvalidAuthSeqNumErr, CoreWLAN.kCWInvalidAuthenticationSequenceNumberErr)
-        self.assertEqual(CoreWLAN.kCWInvalidInfoElementErr, CoreWLAN.kCWInvalidInformationElementErr)
-        self.assertEqual(CoreWLAN.kCWHTFeaturesNotSupported, CoreWLAN.kCWHTFeaturesNotSupportedErr)
-        self.assertEqual(CoreWLAN.kCWPCOTransitionTimeNotSupported, CoreWLAN.kCWPCOTransitionTimeNotSupportedErr)
+        self.assertEqual(
+            CoreWLAN.kCWAuthAlgUnsupportedErr,
+            CoreWLAN.kCWAuthenticationAlgorithmUnsupportedErr,
+        )
+        self.assertEqual(
+            CoreWLAN.kCWInvalidAuthSeqNumErr,
+            CoreWLAN.kCWInvalidAuthenticationSequenceNumberErr,
+        )
+        self.assertEqual(
+            CoreWLAN.kCWInvalidInfoElementErr, CoreWLAN.kCWInvalidInformationElementErr
+        )
+        self.assertEqual(
+            CoreWLAN.kCWHTFeaturesNotSupported, CoreWLAN.kCWHTFeaturesNotSupportedErr
+        )
+        self.assertEqual(
+            CoreWLAN.kCWPCOTransitionTimeNotSupported,
+            CoreWLAN.kCWPCOTransitionTimeNotSupportedErr,
+        )
         self.assertEqual(CoreWLAN.kCWRefNotBoundErr, CoreWLAN.kCWReferenceNotBoundErr)
         self.assertEqual(CoreWLAN.kCWIPCError, CoreWLAN.kCWIPCFailureErr)
-        self.assertEqual(CoreWLAN.kCWOpNotPermitted, CoreWLAN.kCWOperationNotPermittedErr)
+        self.assertEqual(
+            CoreWLAN.kCWOpNotPermitted, CoreWLAN.kCWOperationNotPermittedErr
+        )
         self.assertEqual(CoreWLAN.kCWError, CoreWLAN.kCWErr)
         self.assertEqual(CoreWLAN.kCWPHYMode11A, 0)
         self.assertEqual(CoreWLAN.kCWPHYMode11B, 1)
@@ -111,6 +145,20 @@ class TestCoreWLANTypes (TestCase):
         self.assertEqual(CoreWLAN.kCWScanTypeActive, 0)
         self.assertEqual(CoreWLAN.kCWScanTypePassive, 1)
         self.assertEqual(CoreWLAN.kCWScanTypeFast, 2)
+        self.assertEqual(CoreWLAN.kCWKeychainDomainNone, 0)
+        self.assertEqual(CoreWLAN.kCWKeychainDomainUser, 1)
+        self.assertEqual(CoreWLAN.kCWKeychainDomainSystem, 2)
+        self.assertEqual(CoreWLAN.CWEventTypeNone, 0)
+        self.assertEqual(CoreWLAN.CWEventTypePowerDidChange, 1)
+        self.assertEqual(CoreWLAN.CWEventTypeSSIDDidChange, 2)
+        self.assertEqual(CoreWLAN.CWEventTypeBSSIDDidChange, 3)
+        self.assertEqual(CoreWLAN.CWEventTypeCountryCodeDidChange, 4)
+        self.assertEqual(CoreWLAN.CWEventTypeLinkDidChange, 5)
+        self.assertEqual(CoreWLAN.CWEventTypeLinkQualityDidChange, 6)
+        self.assertEqual(CoreWLAN.CWEventTypeModeDidChange, 7)
+        self.assertEqual(CoreWLAN.CWEventTypeScanCacheUpdated, 8)
+        self.assertEqual(CoreWLAN.CWEventTypeUnknown, Foundation.NSIntegerMax)
 
-if __name__ == "__main__":
-    main()
+        # Introduced in 10.12
+        self.assertEqual(CoreWLAN.CWEventTypeVirtualInterfaceStateChanged, 9)
+        self.assertEqual(CoreWLAN.CWEventTypeRangingReportEvent, 10)
